@@ -10,7 +10,7 @@ from homeassistant.components.sensor import (
     SensorStateClass,
 )
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import VOLUME_GALLONS
+from homeassistant.const import UnitOfVolume
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
@@ -35,45 +35,45 @@ FLUME_QUERIES_SENSOR: tuple[SensorEntityDescription, ...] = (
     SensorEntityDescription(
         key="current_interval",
         name="Current",
-        native_unit_of_measurement=f"{VOLUME_GALLONS}/m",
+        native_unit_of_measurement=f"{UnitOfVolume.GALLONS}/m",
     ),
     SensorEntityDescription(
         key="month_to_date",
         name="Current Month",
-        native_unit_of_measurement=VOLUME_GALLONS,
+        native_unit_of_measurement=UnitOfVolume.GALLONS,
         device_class=SensorDeviceClass.WATER,
         state_class=SensorStateClass.TOTAL_INCREASING,
     ),
     SensorEntityDescription(
         key="week_to_date",
         name="Current Week",
-        native_unit_of_measurement=VOLUME_GALLONS,
+        native_unit_of_measurement=UnitOfVolume.GALLONS,
         device_class=SensorDeviceClass.WATER,
         state_class=SensorStateClass.TOTAL_INCREASING,
     ),
     SensorEntityDescription(
         key="today",
         name="Current Day",
-        native_unit_of_measurement=VOLUME_GALLONS,
+        native_unit_of_measurement=UnitOfVolume.GALLONS,
         device_class=SensorDeviceClass.WATER,
         state_class=SensorStateClass.TOTAL_INCREASING,
     ),
     SensorEntityDescription(
         key="last_60_min",
         name="60 Minutes",
-        native_unit_of_measurement=f"{VOLUME_GALLONS}/h",
+        native_unit_of_measurement=f"{UnitOfVolume.GALLONS}/h",
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key="last_24_hrs",
         name="24 Hours",
-        native_unit_of_measurement=f"{VOLUME_GALLONS}/d",
+        native_unit_of_measurement=f"{UnitOfVolume.GALLONS}/d",
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key="last_30_days",
         name="30 Days",
-        native_unit_of_measurement=f"{VOLUME_GALLONS}/mo",
+        native_unit_of_measurement=f"{UnitOfVolume.GALLONS}/mo",
         state_class=SensorStateClass.MEASUREMENT,
     ),
 )
