@@ -6,9 +6,14 @@ import asyncio
 from collections.abc import Iterable
 from datetime import datetime, timedelta
 import logging
-from typing import Any
+from typing import Any, Union, cast
 
-from gcal_sync.api import GoogleCalendarService, ListEventsRequest, SyncEventsRequest
+from gcal_sync.api import (
+    GoogleCalendarService,
+    ListEventsRequest,
+    Range,
+    SyncEventsRequest,
+)
 from gcal_sync.exceptions import ApiException
 from gcal_sync.model import AccessRole, DateOrDatetime, Event
 from gcal_sync.store import ScopedCalendarStore
@@ -18,7 +23,13 @@ import voluptuous as vol
 
 from homeassistant.components.calendar import (
     ENTITY_ID_FORMAT,
+    EVENT_DESCRIPTION,
+    EVENT_END,
+    EVENT_RRULE,
+    EVENT_START,
+    EVENT_SUMMARY,
     CalendarEntity,
+    CalendarEntityFeature,
     CalendarEvent,
     extract_offset,
     is_offset_reached,
@@ -56,7 +67,6 @@ from .api import get_feature_access
 from .const import (
     DATA_SERVICE,
     DATA_STORE,
-    EVENT_DESCRIPTION,
     EVENT_END_DATE,
     EVENT_END_DATETIME,
     EVENT_IN,
@@ -64,7 +74,6 @@ from .const import (
     EVENT_IN_WEEKS,
     EVENT_START_DATE,
     EVENT_START_DATETIME,
-    EVENT_SUMMARY,
     EVENT_TYPES_CONF,
     FeatureAccess,
 )
@@ -82,6 +91,10 @@ SYNC_EVENT_MIN_TIME = timedelta(days=-90)
 # are not opaque are ignored by default.
 OPAQUE = "opaque"
 
+# Google calendar prefixes recurrence rules with RRULE: which
+# we need to strip when working with the frontend recurrence rule values
+RRULE_PREFIX = "RRULE:"
+
 _EVENT_IN_TYPES = vol.Schema(
     {
         vol.Exclusive(EVENT_IN_DAYS, EVENT_TYPES_CONF): cv.positive_int,
@@ -162,8 +175,9 @@ async def async_setup_entry(
             entity_enabled = data.get(CONF_TRACK, True)
             if not entity_enabled:
                 _LOGGER.warning(
-                    "The 'track' option in google_calendars.yaml has been deprecated. The setting "
-                    "has been imported to the UI, and should now be removed from google_calendars.yaml"
+                    "The 'track' option in google_calendars.yaml has been deprecated."
+                    " The setting has been imported to the UI, and should now be"
+                    " removed from google_calendars.yaml"
                 )
             entity_name = data[CONF_DEVICE_ID]
             # The unique id is based on the config entry and calendar id since multiple accounts
@@ -201,10 +215,13 @@ async def async_setup_entry(
             # Prefer calendar sync down of resources when possible. However, sync does not work
             # for search. Also free-busy calendars denormalize recurring events as individual
             # events which is not efficient for sync
+            support_write = (
+                calendar_item.access_role.is_writer
+                and get_feature_access(hass, config_entry) is FeatureAccess.read_write
+            )
             if (
                 search := data.get(CONF_SEARCH)
-                or calendar_item.access_role == AccessRole.FREE_BUSY_READER
-            ):
+            ) or calendar_item.access_role == AccessRole.FREE_BUSY_READER:
                 coordinator = CalendarQueryUpdateCoordinator(
                     hass,
                     calendar_service,
@@ -212,6 +229,7 @@ async def async_setup_entry(
                     calendar_id,
                     search,
                 )
+                support_write = False
             else:
                 request_template = SyncEventsRequest(
                     calendar_id=calendar_id,
@@ -235,6 +253,7 @@ async def async_setup_entry(
                     generate_entity_id(ENTITY_ID_FORMAT, entity_name, hass=hass),
                     unique_id,
                     entity_enabled,
+                    support_write,
                 )
             )
 
@@ -250,7 +269,10 @@ async def async_setup_entry(
         await hass.async_add_executor_job(append_calendars_to_config)
 
     platform = entity_platform.async_get_current_platform()
-    if get_feature_access(hass, config_entry) is FeatureAccess.read_write:
+    if (
+        any(calendar_item.access_role.is_writer for calendar_item in result.items)
+        and get_feature_access(hass, config_entry) is FeatureAccess.read_write
+    ):
         platform.async_register_entity_service(
             SERVICE_CREATE_EVENT,
             CREATE_EVENT_SCHEMA,
@@ -369,7 +391,12 @@ class CalendarQueryUpdateCoordinator(DataUpdateCoordinator[list[Event]]):
         return self.data
 
 
-class GoogleCalendarEntity(CoordinatorEntity, CalendarEntity):
+class GoogleCalendarEntity(
+    CoordinatorEntity[
+        Union[CalendarSyncUpdateCoordinator, CalendarQueryUpdateCoordinator]
+    ],
+    CalendarEntity,
+):
     """A calendar event entity."""
 
     _attr_has_entity_name = True
@@ -382,10 +409,10 @@ class GoogleCalendarEntity(CoordinatorEntity, CalendarEntity):
         entity_id: str,
         unique_id: str | None,
         entity_enabled: bool,
+        supports_write: bool,
     ) -> None:
         """Create the Calendar event device."""
         super().__init__(coordinator)
-        self.coordinator = coordinator
         self.calendar_id = calendar_id
         self._ignore_availability: bool = data.get(CONF_IGNORE_AVAILABILITY, False)
         self._event: CalendarEvent | None = None
@@ -395,6 +422,10 @@ class GoogleCalendarEntity(CoordinatorEntity, CalendarEntity):
         self.entity_id = entity_id
         self._attr_unique_id = unique_id
         self._attr_entity_registry_enabled_default = entity_enabled
+        if supports_write:
+            self._attr_supported_features = (
+                CalendarEntityFeature.CREATE_EVENT | CalendarEntityFeature.DELETE_EVENT
+            )
 
     @property
     def should_poll(self) -> bool:
@@ -486,10 +517,69 @@ class GoogleCalendarEntity(CoordinatorEntity, CalendarEntity):
         started, handled by CalendarEntity parent class.
         """
 
+    async def async_create_event(self, **kwargs: Any) -> None:
+        """Add a new event to calendar."""
+        dtstart = kwargs[EVENT_START]
+        dtend = kwargs[EVENT_END]
+        start: DateOrDatetime
+        end: DateOrDatetime
+        if isinstance(dtstart, datetime):
+            start = DateOrDatetime(
+                date_time=dt_util.as_local(dtstart),
+                timezone=str(dt_util.DEFAULT_TIME_ZONE),
+            )
+            end = DateOrDatetime(
+                date_time=dt_util.as_local(dtend),
+                timezone=str(dt_util.DEFAULT_TIME_ZONE),
+            )
+        else:
+            start = DateOrDatetime(date=dtstart)
+            end = DateOrDatetime(date=dtend)
+        event = Event.parse_obj(
+            {
+                EVENT_SUMMARY: kwargs[EVENT_SUMMARY],
+                "start": start,
+                "end": end,
+                EVENT_DESCRIPTION: kwargs.get(EVENT_DESCRIPTION),
+            }
+        )
+        if rrule := kwargs.get(EVENT_RRULE):
+            event.recurrence = [f"{RRULE_PREFIX}{rrule}"]
+
+        await cast(
+            CalendarSyncUpdateCoordinator, self.coordinator
+        ).sync.store_service.async_add_event(event)
+        await self.coordinator.async_refresh()
+
+    async def async_delete_event(
+        self,
+        uid: str,
+        recurrence_id: str | None = None,
+        recurrence_range: str | None = None,
+    ) -> None:
+        """Delete an event on the calendar."""
+        range_value: Range = Range.NONE
+        if recurrence_range == Range.THIS_AND_FUTURE:
+            range_value = Range.THIS_AND_FUTURE
+        await cast(
+            CalendarSyncUpdateCoordinator, self.coordinator
+        ).sync.store_service.async_delete_event(
+            ical_uuid=uid,
+            event_id=recurrence_id,
+            recurrence_range=range_value,
+        )
+        await self.coordinator.async_refresh()
+
 
 def _get_calendar_event(event: Event) -> CalendarEvent:
     """Return a CalendarEvent from an API event."""
+    rrule: str | None = None
+    if len(event.recurrence) == 1:
+        rrule = event.recurrence[0].lstrip(RRULE_PREFIX)
     return CalendarEvent(
+        uid=event.ical_uuid,
+        recurrence_id=event.id if event.recurring_event_id else None,
+        rrule=rrule,
         summary=event.summary,
         start=event.start.value,
         end=event.end.value,
@@ -537,7 +627,9 @@ async def async_create_event(entity: GoogleCalendarEntity, call: ServiceCall) ->
         raise ValueError("Missing required fields to set start or end date/datetime")
 
     try:
-        await entity.coordinator.sync.api.async_create_event(
+        await cast(
+            CalendarSyncUpdateCoordinator, entity.coordinator
+        ).sync.api.async_create_event(
             entity.calendar_id,
             Event(
                 summary=call.data[EVENT_SUMMARY],
