@@ -153,7 +153,8 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
 
         if agent_user_id is None:
             _LOGGER.warning(
-                "No agent_user_id supplied for request_sync. Call as a user or pass in user id as agent_user_id"
+                "No agent_user_id supplied for request_sync. Call as a user or pass in"
+                " user id as agent_user_id"
             )
             return
 
