@@ -1,8 +1,5 @@
 """Describe logbook events."""
-from homeassistant.components.logbook.const import (
-    LOGBOOK_ENTRY_MESSAGE,
-    LOGBOOK_ENTRY_NAME,
-)
+from homeassistant.components.logbook import LOGBOOK_ENTRY_MESSAGE, LOGBOOK_ENTRY_NAME
 from homeassistant.core import callback
 
 from .const import DOMAIN, EVENT_COMMAND_RECEIVED, SOURCE_CLOUD
