@@ -35,7 +35,7 @@ from homeassistant.const import (
     CONF_NAME,
     CONF_PORT,
     CONF_TYPE,
-    TEMP_CELSIUS,
+    UnitOfTemperature,
 )
 from homeassistant.core import Event, HomeAssistant, State, callback, split_entity_id
 import homeassistant.helpers.config_validation as cv
@@ -349,7 +349,7 @@ def async_show_setup_message(
 
     message = (
         f"To set up {bridge_name} in the Home App, "
-        f"scan the QR code or enter the following code:\n"
+        "scan the QR code or enter the following code:\n"
         f"### {pin}\n"
         f"![image](/api/homekit/pairingqr?{entry_id}-{pairing_secret})"
     )
@@ -391,12 +391,20 @@ def cleanup_name_for_homekit(name: str | None) -> str:
 
 def temperature_to_homekit(temperature: float | int, unit: str) -> float:
     """Convert temperature to Celsius for HomeKit."""
-    return round(TemperatureConverter.convert(temperature, unit, TEMP_CELSIUS), 1)
+    return round(
+        TemperatureConverter.convert(temperature, unit, UnitOfTemperature.CELSIUS), 1
+    )
 
 
 def temperature_to_states(temperature: float | int, unit: str) -> float:
     """Convert temperature back from Celsius to Home Assistant unit."""
-    return round(TemperatureConverter.convert(temperature, TEMP_CELSIUS, unit) * 2) / 2
+    return (
+        round(
+            TemperatureConverter.convert(temperature, UnitOfTemperature.CELSIUS, unit)
+            * 2
+        )
+        / 2
+    )
 
 
 def density_to_air_quality(density: float) -> int:
