@@ -180,7 +180,8 @@ async def async_setup_entry(
             await isy.initialize()
     except asyncio.TimeoutError as err:
         raise ConfigEntryNotReady(
-            f"Timed out initializing the ISY; device may be busy, trying again later: {err}"
+            "Timed out initializing the ISY; device may be busy, trying again later:"
+            f" {err}"
         ) from err
     except ISYInvalidAuthError as err:
         raise ConfigEntryAuthFailed(f"Invalid credentials for the ISY: {err}") from err
@@ -190,7 +191,12 @@ async def async_setup_entry(
         ) from err
     except ISYResponseParseError as err:
         raise ConfigEntryNotReady(
-            f"Invalid XML response from ISY; Ensure the ISY is running the latest firmware: {err}"
+            "Invalid XML response from ISY; Ensure the ISY is running the latest"
+            f" firmware: {err}"
+        ) from err
+    except TypeError as err:
+        raise ConfigEntryNotReady(
+            f"Invalid response ISY, device is likely still starting: {err}"
         ) from err
 
     _categorize_nodes(hass_isy_data, isy.nodes, ignore_identifier, sensor_identifier)
@@ -204,7 +210,7 @@ async def async_setup_entry(
     _async_get_or_create_isy_device_in_registry(hass, entry, isy)
 
     # Load platforms for the devices in the ISY controller that we support.
-    hass.config_entries.async_setup_platforms(entry, PLATFORMS)
+    await hass.config_entries.async_forward_entry_setups(entry, PLATFORMS)
 
     @callback
     def _async_stop_auto_update(event: Event) -> None:
