@@ -17,37 +17,11 @@ from homeassistant.const import (
     CURRENCY_CENT,
     CURRENCY_DOLLAR,
     DEGREE,
-    ELECTRIC_CURRENT_MILLIAMPERE,
-    ELECTRIC_POTENTIAL_MILLIVOLT,
-    ELECTRIC_POTENTIAL_VOLT,
-    ENERGY_KILO_WATT_HOUR,
-    ENERGY_WATT_HOUR,
-    FREQUENCY_HERTZ,
-    IRRADIATION_WATTS_PER_SQUARE_METER,
-    LENGTH_CENTIMETERS,
-    LENGTH_FEET,
-    LENGTH_INCHES,
-    LENGTH_KILOMETERS,
-    LENGTH_METERS,
-    LENGTH_MILES,
-    LENGTH_MILLIMETERS,
     LIGHT_LUX,
-    MASS_KILOGRAMS,
-    MASS_POUNDS,
     PERCENTAGE,
-    POWER_KILO_WATT,
-    POWER_WATT,
-    PRESSURE_HPA,
-    PRESSURE_INHG,
-    PRESSURE_MBAR,
     REVOLUTIONS_PER_MINUTE,
     SERVICE_LOCK,
     SERVICE_UNLOCK,
-    SOUND_PRESSURE_DB,
-    SOUND_PRESSURE_WEIGHTED_DBA,
-    SPEED_KILOMETERS_PER_HOUR,
-    SPEED_METERS_PER_SECOND,
-    SPEED_MILES_PER_HOUR,
     STATE_CLOSED,
     STATE_CLOSING,
     STATE_LOCKED,
@@ -58,24 +32,23 @@ from homeassistant.const import (
     STATE_PROBLEM,
     STATE_UNKNOWN,
     STATE_UNLOCKED,
-    TEMP_CELSIUS,
-    TEMP_FAHRENHEIT,
-    TEMP_KELVIN,
-    TIME_DAYS,
-    TIME_HOURS,
-    TIME_MILLISECONDS,
-    TIME_MINUTES,
-    TIME_MONTHS,
-    TIME_SECONDS,
-    TIME_YEARS,
     UV_INDEX,
-    VOLUME_CUBIC_FEET,
-    VOLUME_CUBIC_METERS,
-    VOLUME_FLOW_RATE_CUBIC_FEET_PER_MINUTE,
-    VOLUME_FLOW_RATE_CUBIC_METERS_PER_HOUR,
-    VOLUME_GALLONS,
-    VOLUME_LITERS,
     Platform,
+    UnitOfElectricCurrent,
+    UnitOfElectricPotential,
+    UnitOfEnergy,
+    UnitOfFrequency,
+    UnitOfIrradiance,
+    UnitOfLength,
+    UnitOfMass,
+    UnitOfPower,
+    UnitOfPressure,
+    UnitOfSoundPressure,
+    UnitOfSpeed,
+    UnitOfTemperature,
+    UnitOfTime,
+    UnitOfVolume,
+    UnitOfVolumeFlowRate,
     UnitOfVolumetricFlux,
 )
 
@@ -320,59 +293,59 @@ NODE_FILTERS: dict[Platform, dict[str, list[str]]] = {
 UOM_FRIENDLY_NAME = {
     "1": "A",
     UOM_ON_OFF: "",  # Binary, no unit
-    "3": f"btu/{TIME_HOURS}",
-    "4": TEMP_CELSIUS,
-    "5": LENGTH_CENTIMETERS,
-    "6": VOLUME_CUBIC_FEET,
-    "7": VOLUME_FLOW_RATE_CUBIC_FEET_PER_MINUTE,
-    "8": VOLUME_CUBIC_METERS,
-    "9": TIME_DAYS,
-    "10": TIME_DAYS,
-    "12": SOUND_PRESSURE_DB,
-    "13": SOUND_PRESSURE_WEIGHTED_DBA,
+    "3": f"btu/{UnitOfTime.HOURS}",
+    "4": UnitOfTemperature.CELSIUS,
+    "5": UnitOfLength.CENTIMETERS,
+    "6": UnitOfVolume.CUBIC_FEET,
+    "7": UnitOfVolumeFlowRate.CUBIC_FEET_PER_MINUTE,
+    "8": UnitOfVolume.CUBIC_METERS,
+    "9": UnitOfTime.DAYS,
+    "10": UnitOfTime.DAYS,
+    "12": UnitOfSoundPressure.DECIBEL,
+    "13": UnitOfSoundPressure.WEIGHTED_DECIBEL_A,
     "14": DEGREE,
     "16": "macroseismic",
-    "17": TEMP_FAHRENHEIT,
-    "18": LENGTH_FEET,
-    "19": TIME_HOURS,
-    "20": TIME_HOURS,
+    "17": UnitOfTemperature.FAHRENHEIT,
+    "18": UnitOfLength.FEET,
+    "19": UnitOfTime.HOURS,
+    "20": UnitOfTime.HOURS,
     "21": "%AH",
     "22": "%RH",
-    "23": PRESSURE_INHG,
+    "23": UnitOfPressure.INHG,
     "24": UnitOfVolumetricFlux.INCHES_PER_HOUR,
     UOM_INDEX: UOM_INDEX,  # Index type. Use "node.formatted" for value
-    "26": TEMP_KELVIN,
+    "26": UnitOfTemperature.KELVIN,
     "27": "keyword",
-    "28": MASS_KILOGRAMS,
+    "28": UnitOfMass.KILOGRAMS,
     "29": "kV",
-    "30": POWER_KILO_WATT,
+    "30": UnitOfPower.KILO_WATT,
     "31": "kPa",
-    "32": SPEED_KILOMETERS_PER_HOUR,
-    "33": ENERGY_KILO_WATT_HOUR,
+    "32": UnitOfSpeed.KILOMETERS_PER_HOUR,
+    "33": UnitOfEnergy.KILO_WATT_HOUR,
     "34": "liedu",
-    "35": VOLUME_LITERS,
+    "35": UnitOfVolume.LITERS,
     "36": LIGHT_LUX,
     "37": "mercalli",
-    "38": LENGTH_METERS,
-    "39": VOLUME_FLOW_RATE_CUBIC_METERS_PER_HOUR,
-    "40": SPEED_METERS_PER_SECOND,
-    "41": ELECTRIC_CURRENT_MILLIAMPERE,
-    "42": TIME_MILLISECONDS,
-    "43": ELECTRIC_POTENTIAL_MILLIVOLT,
-    "44": TIME_MINUTES,
-    "45": TIME_MINUTES,
+    "38": UnitOfLength.METERS,
+    "39": UnitOfVolumeFlowRate.CUBIC_METERS_PER_HOUR,
+    "40": UnitOfSpeed.METERS_PER_SECOND,
+    "41": UnitOfElectricCurrent.MILLIAMPERE,
+    "42": UnitOfTime.MILLISECONDS,
+    "43": UnitOfElectricPotential.MILLIVOLT,
+    "44": UnitOfTime.MINUTES,
+    "45": UnitOfTime.MINUTES,
     "46": UnitOfVolumetricFlux.MILLIMETERS_PER_HOUR,
-    "47": TIME_MONTHS,
-    "48": SPEED_MILES_PER_HOUR,
-    "49": SPEED_METERS_PER_SECOND,
+    "47": UnitOfTime.MONTHS,
+    "48": UnitOfSpeed.MILES_PER_HOUR,
+    "49": UnitOfSpeed.METERS_PER_SECOND,
     "50": "Ω",
     UOM_PERCENTAGE: PERCENTAGE,
-    "52": MASS_POUNDS,
+    "52": UnitOfMass.POUNDS,
     "53": "pf",
     "54": CONCENTRATION_PARTS_PER_MILLION,
     "55": "pulse count",
-    "57": TIME_SECONDS,
-    "58": TIME_SECONDS,
+    "57": UnitOfTime.SECONDS,
+    "58": UnitOfTime.SECONDS,
     "59": "S/m",
     "60": "m_b",
     "61": "M_L",
@@ -380,22 +353,22 @@ UOM_FRIENDLY_NAME = {
     "63": "M_S",
     "64": "shindo",
     "65": "SML",
-    "69": VOLUME_GALLONS,
+    "69": UnitOfVolume.GALLONS,
     "71": UV_INDEX,
-    "72": ELECTRIC_POTENTIAL_VOLT,
-    "73": POWER_WATT,
-    "74": IRRADIATION_WATTS_PER_SQUARE_METER,
+    "72": UnitOfElectricPotential.VOLT,
+    "73": UnitOfPower.WATT,
+    "74": UnitOfIrradiance.WATTS_PER_SQUARE_METER,
     "75": "weekday",
     "76": DEGREE,
-    "77": TIME_YEARS,
-    "82": LENGTH_MILLIMETERS,
-    "83": LENGTH_KILOMETERS,
+    "77": UnitOfTime.YEARS,
+    "82": UnitOfLength.MILLIMETERS,
+    "83": UnitOfLength.KILOMETERS,
     "85": "Ω",
     "86": "kΩ",
-    "87": f"{VOLUME_CUBIC_METERS}/{VOLUME_CUBIC_METERS}",
+    "87": f"{UnitOfVolume.CUBIC_METERS}/{UnitOfVolume.CUBIC_METERS}",
     "88": "Water activity",
     "89": REVOLUTIONS_PER_MINUTE,
-    "90": FREQUENCY_HERTZ,
+    "90": UnitOfFrequency.HERTZ,
     "91": DEGREE,
     "92": f"{DEGREE} South",
     UOM_8_BIT_RANGE: "",  # Range 0-255, no unit.
@@ -403,7 +376,7 @@ UOM_FRIENDLY_NAME = {
     "102": "kWs",
     "103": CURRENCY_DOLLAR,
     "104": CURRENCY_CENT,
-    "105": LENGTH_INCHES,
+    "105": UnitOfLength.INCHES,
     "106": UnitOfVolumetricFlux.MILLIMETERS_PER_DAY,
     "107": "",  # raw 1-byte unsigned value
     "108": "",  # raw 2-byte unsigned value
@@ -413,10 +386,10 @@ UOM_FRIENDLY_NAME = {
     "112": "",  # raw 2-byte signed value
     "113": "",  # raw 3-byte signed value
     "114": "",  # raw 4-byte signed value
-    "116": LENGTH_MILES,
-    "117": PRESSURE_MBAR,
-    "118": PRESSURE_HPA,
-    "119": ENERGY_WATT_HOUR,
+    "116": UnitOfLength.MILES,
+    "117": UnitOfPressure.MBAR,
+    "118": UnitOfPressure.HPA,
+    "119": UnitOfEnergy.WATT_HOUR,
     "120": UnitOfVolumetricFlux.INCHES_PER_DAY,
 }
 
