@@ -31,7 +31,9 @@ class JuiceNetDevice(CoordinatorEntity):
     def device_info(self) -> DeviceInfo:
         """Return device information about this JuiceNet Device."""
         return DeviceInfo(
-            configuration_url=f"https://home.juice.net/Portal/Details?unitID={self.device.id}",
+            configuration_url=(
+                f"https://home.juice.net/Portal/Details?unitID={self.device.id}"
+            ),
             identifiers={(DOMAIN, self.device.id)},
             manufacturer="JuiceNet",
             name=self.device.name,
