@@ -83,6 +83,7 @@ async def _async_send_historical_events(
     formatter: Callable[[int, Any], dict[str, Any]],
     event_processor: EventProcessor,
     partial: bool,
+    force_send: bool = False,
 ) -> dt | None:
     """Select historical data from the database and deliver it to the websocket.
 
@@ -116,7 +117,7 @@ async def _async_send_historical_events(
         # if its the last one (not partial) so
         # consumers of the api know their request was
         # answered but there were no results
-        if last_event_time or not partial:
+        if last_event_time or not partial or force_send:
             connection.send_message(message)
         return last_event_time
 
@@ -150,7 +151,7 @@ async def _async_send_historical_events(
     # if its the last one (not partial) so
     # consumers of the api know their request was
     # answered but there were no results
-    if older_query_last_event_time or not partial:
+    if older_query_last_event_time or not partial or force_send:
         connection.send_message(older_message)
 
     # Returns the time of the newest event
@@ -384,6 +385,11 @@ async def ws_event_stream(
         messages.event_message,
         event_processor,
         partial=True,
+        # Force a send since the wait for the sync task
+        # can take a a while if the recorder is busy and
+        # we want to make sure the client is not still spinning
+        # because it is waiting for the first message
+        force_send=True,
     )
 
     live_stream.task = asyncio.create_task(
