@@ -6,7 +6,7 @@ import contextlib
 from itertools import chain
 import logging
 import ssl
-from typing import Any
+from typing import Any, cast
 
 import async_timeout
 from pylutron_caseta import BUTTON_STATUS_PRESSED
@@ -28,6 +28,7 @@ from .const import (
     ATTR_ACTION,
     ATTR_AREA_NAME,
     ATTR_BUTTON_NUMBER,
+    ATTR_BUTTON_TYPE,
     ATTR_DEVICE_NAME,
     ATTR_LEAP_BUTTON_NUMBER,
     ATTR_SERIAL,
@@ -37,6 +38,7 @@ from .const import (
     CONF_CA_CERTS,
     CONF_CERTFILE,
     CONF_KEYFILE,
+    CONF_SUBTYPE,
     CONFIG_URL,
     DOMAIN,
     LUTRON_CASETA_BUTTON_EVENT,
@@ -45,10 +47,25 @@ from .const import (
 )
 from .device_trigger import (
     DEVICE_TYPE_SUBTYPE_MAP_TO_LIP,
+    KEYPAD_LEAP_BUTTON_NAME_OVERRIDE,
     LEAP_TO_DEVICE_TYPE_SUBTYPE_MAP,
-    _lutron_model_to_device_type,
+    LUTRON_BUTTON_TRIGGER_SCHEMA,
+)
+from .models import (
+    LUTRON_BUTTON_LEAP_BUTTON_NUMBER,
+    LUTRON_KEYPAD_AREA_NAME,
+    LUTRON_KEYPAD_BUTTONS,
+    LUTRON_KEYPAD_DEVICE_REGISTRY_DEVICE_ID,
+    LUTRON_KEYPAD_LUTRON_DEVICE_ID,
+    LUTRON_KEYPAD_MODEL,
+    LUTRON_KEYPAD_NAME,
+    LUTRON_KEYPAD_SERIAL,
+    LUTRON_KEYPAD_TYPE,
+    LutronButton,
+    LutronCasetaData,
+    LutronKeypad,
+    LutronKeypadData,
 )
-from .models import LutronCasetaData
 from .util import serial_to_unique_id
 
 _LOGGER = logging.getLogger(__name__)
@@ -79,6 +96,7 @@ PLATFORMS = [
     Platform.LIGHT,
     Platform.SCENE,
     Platform.SWITCH,
+    Platform.BUTTON,
 ]
 
 
@@ -168,24 +186,25 @@ async def async_setup_entry(
     _LOGGER.debug("Connected to Lutron Caseta bridge via LEAP at %s", host)
     await _async_migrate_unique_ids(hass, config_entry)
 
-    devices = bridge.get_devices()
-    bridge_device = devices[BRIDGE_DEVICE_ID]
+    bridge_devices = bridge.get_devices()
+    bridge_device = bridge_devices[BRIDGE_DEVICE_ID]
+
     if not config_entry.unique_id:
         hass.config_entries.async_update_entry(
             config_entry, unique_id=serial_to_unique_id(bridge_device["serial"])
         )
 
-    buttons = bridge.buttons
-    _async_register_bridge_device(hass, entry_id, bridge_device)
-    button_devices = _async_register_button_devices(
-        hass, entry_id, bridge_device, buttons
-    )
-    _async_subscribe_pico_remote_events(hass, bridge, buttons)
+    _async_register_bridge_device(hass, entry_id, bridge_device, bridge)
+
+    keypad_data = _async_setup_keypads(hass, entry_id, bridge, bridge_device)
 
     # Store this bridge (keyed by entry_id) so it can be retrieved by the
     # platforms we're setting up.
+
     hass.data[DOMAIN][entry_id] = LutronCasetaData(
-        bridge, bridge_device, button_devices
+        bridge,
+        bridge_device,
+        keypad_data,
     )
 
     await hass.config_entries.async_forward_entry_setups(config_entry, PLATFORMS)
@@ -195,60 +214,220 @@ async def async_setup_entry(
 
 @callback
 def _async_register_bridge_device(
-    hass: HomeAssistant, config_entry_id: str, bridge_device: dict
+    hass: HomeAssistant, config_entry_id: str, bridge_device: dict, bridge: Smartbridge
 ) -> None:
     """Register the bridge device in the device registry."""
     device_registry = dr.async_get(hass)
-    device_registry.async_get_or_create(
-        name=bridge_device["name"],
-        manufacturer=MANUFACTURER,
-        config_entry_id=config_entry_id,
-        identifiers={(DOMAIN, bridge_device["serial"])},
-        model=f"{bridge_device['model']} ({bridge_device['type']})",
-        configuration_url="https://device-login.lutron.com",
+
+    device_args: DeviceInfo = {
+        "name": bridge_device["name"],
+        "manufacturer": MANUFACTURER,
+        "identifiers": {(DOMAIN, bridge_device["serial"])},
+        "model": f"{bridge_device['model']} ({bridge_device['type']})",
+        "via_device": (DOMAIN, bridge_device["serial"]),
+        "configuration_url": "https://device-login.lutron.com",
+    }
+
+    area = _area_name_from_id(bridge.areas, bridge_device["area"])
+    if area != UNASSIGNED_AREA:
+        device_args["suggested_area"] = area
+
+    device_registry.async_get_or_create(**device_args, config_entry_id=config_entry_id)
+
+
+@callback
+def _async_setup_keypads(
+    hass: HomeAssistant,
+    config_entry_id: str,
+    bridge: Smartbridge,
+    bridge_device: dict[str, str | int],
+) -> LutronKeypadData:
+    """Register keypad devices (Keypads and Pico Remotes) in the device registry."""
+
+    device_registry = dr.async_get(hass)
+
+    bridge_devices: dict[str, dict[str, str | int]] = bridge.get_devices()
+    bridge_buttons: dict[str, dict[str, str | int]] = bridge.buttons
+
+    dr_device_id_to_keypad: dict[str, LutronKeypad] = {}
+    keypads: dict[int, LutronKeypad] = {}
+    keypad_buttons: dict[int, LutronButton] = {}
+    keypad_button_names_to_leap: dict[int, dict[str, int]] = {}
+    leap_to_keypad_button_names: dict[int, dict[int, str]] = {}
+
+    for bridge_button in bridge_buttons.values():
+
+        parent_device = cast(str, bridge_button["parent_device"])
+        bridge_keypad = bridge_devices[parent_device]
+        keypad_lutron_device_id = cast(int, bridge_keypad["device_id"])
+        button_lutron_device_id = cast(int, bridge_button["device_id"])
+        leap_button_number = cast(int, bridge_button["button_number"])
+        button_led_device_id = None
+        if "button_led" in bridge_button:
+            button_led_device_id = cast(str, bridge_button["button_led"])
+
+        if not (keypad := keypads.get(keypad_lutron_device_id)):
+            # First time seeing this keypad, build keypad data and store in keypads
+            keypad = keypads[keypad_lutron_device_id] = _async_build_lutron_keypad(
+                bridge, bridge_device, bridge_keypad, keypad_lutron_device_id
+            )
+
+            # Register the keypad device
+            dr_device = device_registry.async_get_or_create(
+                **keypad["device_info"], config_entry_id=config_entry_id
+            )
+            keypad[LUTRON_KEYPAD_DEVICE_REGISTRY_DEVICE_ID] = dr_device.id
+            dr_device_id_to_keypad[dr_device.id] = keypad
+
+        button_name = _get_button_name(keypad, bridge_button)
+        keypad_lutron_device_id = keypad[LUTRON_KEYPAD_LUTRON_DEVICE_ID]
+
+        # Add button to parent keypad, and build keypad_buttons and keypad_button_names_to_leap
+        keypad_buttons[button_lutron_device_id] = LutronButton(
+            lutron_device_id=button_lutron_device_id,
+            leap_button_number=leap_button_number,
+            button_name=button_name,
+            led_device_id=button_led_device_id,
+            parent_keypad=keypad_lutron_device_id,
+        )
+
+        keypad[LUTRON_KEYPAD_BUTTONS].append(button_lutron_device_id)
+
+        button_name_to_leap = keypad_button_names_to_leap.setdefault(
+            keypad_lutron_device_id, {}
+        )
+        button_name_to_leap[button_name] = leap_button_number
+        leap_to_button_name = leap_to_keypad_button_names.setdefault(
+            keypad_lutron_device_id, {}
+        )
+        leap_to_button_name[leap_button_number] = button_name
+
+    keypad_trigger_schemas = _async_build_trigger_schemas(keypad_button_names_to_leap)
+
+    _async_subscribe_keypad_events(
+        hass=hass,
+        bridge=bridge,
+        keypads=keypads,
+        keypad_buttons=keypad_buttons,
+        leap_to_keypad_button_names=leap_to_keypad_button_names,
+    )
+
+    return LutronKeypadData(
+        dr_device_id_to_keypad,
+        keypads,
+        keypad_buttons,
+        keypad_button_names_to_leap,
+        keypad_trigger_schemas,
     )
 
 
 @callback
-def _async_register_button_devices(
-    hass: HomeAssistant,
-    config_entry_id: str,
-    bridge_device,
-    button_devices_by_id: dict[int, dict],
-) -> dict[str, dict]:
-    """Register button devices (Pico Remotes) in the device registry."""
-    device_registry = dr.async_get(hass)
-    button_devices_by_dr_id: dict[str, dict] = {}
-    seen = set()
+def _async_build_trigger_schemas(
+    keypad_button_names_to_leap: dict[int, dict[str, int]]
+) -> dict[int, vol.Schema]:
+    """Build device trigger schemas."""
 
-    for device in button_devices_by_id.values():
-        if "serial" not in device or device["serial"] in seen:
-            continue
-        seen.add(device["serial"])
-        area, name = _area_and_name_from_name(device["name"])
-        device_args: dict[str, Any] = {
-            "name": f"{area} {name}",
-            "manufacturer": MANUFACTURER,
-            "config_entry_id": config_entry_id,
-            "identifiers": {(DOMAIN, device["serial"])},
-            "model": f"{device['model']} ({device['type']})",
-            "via_device": (DOMAIN, bridge_device["serial"]),
-        }
-        if area != UNASSIGNED_AREA:
-            device_args["suggested_area"] = area
-
-        dr_device = device_registry.async_get_or_create(**device_args)
-        button_devices_by_dr_id[dr_device.id] = device
-
-    return button_devices_by_dr_id
+    return {
+        keypad_id: LUTRON_BUTTON_TRIGGER_SCHEMA.extend(
+            {
+                vol.Required(CONF_SUBTYPE): vol.In(
+                    keypad_button_names_to_leap[keypad_id]
+                ),
+            }
+        )
+        for keypad_id in keypad_button_names_to_leap
+    }
 
 
-def _area_and_name_from_name(device_name: str) -> tuple[str, str]:
-    """Return the area and name from the devices internal name."""
-    if "_" in device_name:
-        area_device_name = device_name.split("_", 1)
-        return area_device_name[0], area_device_name[1]
-    return UNASSIGNED_AREA, device_name
+@callback
+def _async_build_lutron_keypad(
+    bridge: Smartbridge,
+    bridge_device: dict[str, Any],
+    bridge_keypad: dict[str, Any],
+    keypad_device_id: int,
+) -> LutronKeypad:
+    # First time seeing this keypad, build keypad data and store in keypads
+    area_name = _area_name_from_id(bridge.areas, bridge_keypad["area"])
+    keypad_name = bridge_keypad["name"].split("_")[-1]
+    keypad_serial = _handle_none_keypad_serial(bridge_keypad, bridge_device["serial"])
+    device_info = DeviceInfo(
+        name=f"{area_name} {keypad_name}",
+        manufacturer=MANUFACTURER,
+        identifiers={(DOMAIN, keypad_serial)},
+        model=f"{bridge_keypad['model']} ({bridge_keypad['type']})",
+        via_device=(DOMAIN, bridge_device["serial"]),
+    )
+    if area_name != UNASSIGNED_AREA:
+        device_info["suggested_area"] = area_name
+
+    return LutronKeypad(
+        lutron_device_id=keypad_device_id,
+        dr_device_id="",
+        area_id=bridge_keypad["area"],
+        area_name=area_name,
+        name=keypad_name,
+        serial=keypad_serial,
+        device_info=device_info,
+        model=bridge_keypad["model"],
+        type=bridge_keypad["type"],
+        buttons=[],
+    )
+
+
+def _get_button_name(keypad: LutronKeypad, bridge_button: dict[str, Any]) -> str:
+    """Get the LEAP button name and check for override."""
+
+    button_number = bridge_button["button_number"]
+    button_name = bridge_button.get("device_name")
+
+    if button_name is None:
+        # This is a Caseta Button retrieve name from hardcoded trigger definitions.
+        return _get_button_name_from_triggers(keypad, button_number)
+
+    keypad_model = keypad[LUTRON_KEYPAD_MODEL]
+    if keypad_model_override := KEYPAD_LEAP_BUTTON_NAME_OVERRIDE.get(keypad_model):
+        if alt_button_name := keypad_model_override.get(button_number):
+            return alt_button_name
+
+    return button_name
+
+
+def _get_button_name_from_triggers(keypad: LutronKeypad, button_number: int) -> str:
+    """Retrieve the caseta button name from device triggers."""
+    button_number_map = LEAP_TO_DEVICE_TYPE_SUBTYPE_MAP.get(keypad["type"], {})
+    return (
+        button_number_map.get(
+            button_number,
+            f"button {button_number}",
+        )
+        .replace("_", " ")
+        .title()
+    )
+
+
+def _handle_none_keypad_serial(keypad_device: dict, bridge_serial: int) -> str:
+    return keypad_device["serial"] or f"{bridge_serial}_{keypad_device['device_id']}"
+
+
+def _area_name_from_id(areas: dict[str, dict], area_id: str | None) -> str:
+    """Return the full area name including parent(s)."""
+    if area_id is None:
+        return UNASSIGNED_AREA
+    return _construct_area_name_from_id(areas, area_id, [])
+
+
+def _construct_area_name_from_id(
+    areas: dict[str, dict], area_id: str, labels: list[str]
+) -> str:
+    """Recursively construct the full area name including parent(s)."""
+    area = areas[area_id]
+    parent_area_id = area["parent_id"]
+    if parent_area_id is None:
+        # This is the root area, return last area
+        return " ".join(labels)
+
+    labels.insert(0, area["name"])
+    return _construct_area_name_from_id(areas, parent_area_id, labels)
 
 
 @callback
@@ -264,17 +443,20 @@ def async_get_lip_button(device_type: str, leap_button: int) -> int | None:
 
 
 @callback
-def _async_subscribe_pico_remote_events(
+def _async_subscribe_keypad_events(
     hass: HomeAssistant,
-    bridge_device: Smartbridge,
-    button_devices_by_id: dict[int, dict],
+    bridge: Smartbridge,
+    keypads: dict[int, LutronKeypad],
+    keypad_buttons: dict[int, LutronButton],
+    leap_to_keypad_button_names: dict[int, dict[int, str]],
 ):
     """Subscribe to lutron events."""
-    dev_reg = dr.async_get(hass)
 
     @callback
     def _async_button_event(button_id, event_type):
-        if not (device := button_devices_by_id.get(button_id)):
+        if not (button := keypad_buttons.get(button_id)) or not (
+            keypad := keypads.get(button["parent_keypad"])
+        ):
             return
 
         if event_type == BUTTON_STATUS_PRESSED:
@@ -282,28 +464,31 @@ def _async_subscribe_pico_remote_events(
         else:
             action = ACTION_RELEASE
 
-        type_ = _lutron_model_to_device_type(device["model"], device["type"])
-        area, name = _area_and_name_from_name(device["name"])
-        leap_button_number = device["button_number"]
-        lip_button_number = async_get_lip_button(type_, leap_button_number)
-        hass_device = dev_reg.async_get_device({(DOMAIN, device["serial"])})
+        keypad_type = keypad[LUTRON_KEYPAD_TYPE]
+        keypad_device_id = keypad[LUTRON_KEYPAD_LUTRON_DEVICE_ID]
+        leap_button_number = button[LUTRON_BUTTON_LEAP_BUTTON_NUMBER]
+        lip_button_number = async_get_lip_button(keypad_type, leap_button_number)
+        button_type = LEAP_TO_DEVICE_TYPE_SUBTYPE_MAP.get(
+            keypad_type, leap_to_keypad_button_names[keypad_device_id]
+        )[leap_button_number]
 
         hass.bus.async_fire(
             LUTRON_CASETA_BUTTON_EVENT,
             {
-                ATTR_SERIAL: device["serial"],
-                ATTR_TYPE: type_,
+                ATTR_SERIAL: keypad[LUTRON_KEYPAD_SERIAL],
+                ATTR_TYPE: keypad_type,
                 ATTR_BUTTON_NUMBER: lip_button_number,
                 ATTR_LEAP_BUTTON_NUMBER: leap_button_number,
-                ATTR_DEVICE_NAME: name,
-                ATTR_DEVICE_ID: hass_device.id,
-                ATTR_AREA_NAME: area,
+                ATTR_DEVICE_NAME: keypad[LUTRON_KEYPAD_NAME],
+                ATTR_DEVICE_ID: keypad[LUTRON_KEYPAD_DEVICE_REGISTRY_DEVICE_ID],
+                ATTR_AREA_NAME: keypad[LUTRON_KEYPAD_AREA_NAME],
+                ATTR_BUTTON_TYPE: button_type,
                 ATTR_ACTION: action,
             },
         )
 
-    for button_id in button_devices_by_id:
-        bridge_device.add_button_subscriber(
+    for button_id in keypad_buttons:
+        bridge.add_button_subscriber(
             str(button_id),
             lambda event_type, button_id=button_id: _async_button_event(
                 button_id, event_type
@@ -314,7 +499,7 @@ def _async_subscribe_pico_remote_events(
 async def async_unload_entry(
     hass: HomeAssistant, entry: config_entries.ConfigEntry
 ) -> bool:
-    """Unload the bridge bridge from a config entry."""
+    """Unload the bridge from a config entry."""
     data: LutronCasetaData = hass.data[DOMAIN][entry.entry_id]
     await data.bridge.close()
     if unload_ok := await hass.config_entries.async_unload_platforms(entry, PLATFORMS):
@@ -327,7 +512,7 @@ class LutronCasetaDevice(Entity):
 
     _attr_should_poll = False
 
-    def __init__(self, device, bridge, bridge_device):
+    def __init__(self, device: dict[str, Any], data: LutronCasetaData) -> None:
         """Set up the base class.
 
         [:param]device the device metadata
@@ -335,15 +520,25 @@ class LutronCasetaDevice(Entity):
         [:param]bridge_device a dict with the details of the bridge
         """
         self._device = device
-        self._smartbridge = bridge
-        self._bridge_device = bridge_device
-        self._bridge_unique_id = serial_to_unique_id(bridge_device["serial"])
+        self._smartbridge = data.bridge
+        self._bridge_device = data.bridge_device
+        self._bridge_unique_id = serial_to_unique_id(data.bridge_device["serial"])
         if "serial" not in self._device:
             return
-        area, name = _area_and_name_from_name(device["name"])
+
+        if "parent_device" in device:
+            # This is a child entity, handle the naming in button.py and switch.py
+            return
+        area = _area_name_from_id(self._smartbridge.areas, device["area"])
+        name = device["name"].split("_")[-1]
         self._attr_name = full_name = f"{area} {name}"
         info = DeviceInfo(
-            identifiers={(DOMAIN, self._handle_none_serial(self.serial))},
+            # Historically we used the device serial number for the identifier
+            # but the serial is usually an integer and a string is expected
+            # here. Since it would be a breaking change to change the identifier
+            # we are ignoring the type error here until it can be migrated to
+            # a string in a future release.
+            identifiers={(DOMAIN, self._handle_none_serial(self.serial))},  # type: ignore[arg-type]
             manufacturer=MANUFACTURER,
             model=f"{device['model']} ({device['type']})",
             name=full_name,
@@ -358,7 +553,7 @@ class LutronCasetaDevice(Entity):
         """Register callbacks."""
         self._smartbridge.add_subscriber(self.device_id, self.async_write_ha_state)
 
-    def _handle_none_serial(self, serial: str | None) -> str | int:
+    def _handle_none_serial(self, serial: str | int | None) -> str | int:
         """Handle None serial returned by RA3 and QSX processors."""
         if serial is None:
             return f"{self._bridge_unique_id}_{self.device_id}"
@@ -370,7 +565,7 @@ class LutronCasetaDevice(Entity):
         return self._device["device_id"]
 
     @property
-    def serial(self):
+    def serial(self) -> int | None:
         """Return the serial number of the device."""
         return self._device["serial"]
 
@@ -382,7 +577,12 @@ class LutronCasetaDevice(Entity):
     @property
     def extra_state_attributes(self):
         """Return the state attributes."""
-        return {"device_id": self.device_id, "zone_id": self._device["zone"]}
+        attributes = {
+            "device_id": self.device_id,
+        }
+        if zone := self._device.get("zone"):
+            attributes["zone_id"] = zone
+        return attributes
 
 
 class LutronCasetaDeviceUpdatableEntity(LutronCasetaDevice):
