@@ -2,6 +2,7 @@
 from __future__ import annotations
 
 import logging
+from typing import Any
 
 from pymediaroom import (
     COMMANDS,
@@ -16,19 +17,15 @@ from homeassistant.components.media_player import (
     PLATFORM_SCHEMA,
     MediaPlayerEntity,
     MediaPlayerEntityFeature,
+    MediaPlayerState,
+    MediaType,
 )
-from homeassistant.components.media_player.const import MEDIA_TYPE_CHANNEL
 from homeassistant.const import (
     CONF_HOST,
     CONF_NAME,
     CONF_OPTIMISTIC,
     CONF_TIMEOUT,
     EVENT_HOMEASSISTANT_STOP,
-    STATE_OFF,
-    STATE_PAUSED,
-    STATE_PLAYING,
-    STATE_STANDBY,
-    STATE_UNAVAILABLE,
 )
 from homeassistant.core import HomeAssistant, callback
 import homeassistant.helpers.config_validation as cv
@@ -117,6 +114,7 @@ async def async_setup_platform(
 class MediaroomDevice(MediaPlayerEntity):
     """Representation of a Mediaroom set-up-box on the network."""
 
+    _attr_media_content_type = MediaType.CHANNEL
     _attr_should_poll = False
     _attr_supported_features = (
         MediaPlayerEntityFeature.PAUSE
@@ -135,16 +133,16 @@ class MediaroomDevice(MediaPlayerEntity):
         """Map pymediaroom state to HA state."""
 
         state_map = {
-            State.OFF: STATE_OFF,
-            State.STANDBY: STATE_STANDBY,
-            State.PLAYING_LIVE_TV: STATE_PLAYING,
-            State.PLAYING_RECORDED_TV: STATE_PLAYING,
-            State.PLAYING_TIMESHIFT_TV: STATE_PLAYING,
-            State.STOPPED: STATE_PAUSED,
-            State.UNKNOWN: STATE_UNAVAILABLE,
+            State.OFF: MediaPlayerState.OFF,
+            State.STANDBY: MediaPlayerState.STANDBY,
+            State.PLAYING_LIVE_TV: MediaPlayerState.PLAYING,
+            State.PLAYING_RECORDED_TV: MediaPlayerState.PLAYING,
+            State.PLAYING_TIMESHIFT_TV: MediaPlayerState.PLAYING,
+            State.STOPPED: MediaPlayerState.PAUSED,
+            State.UNKNOWN: None,
         }
 
-        self._state = state_map[mediaroom_state]
+        self._attr_state = state_map[mediaroom_state]
 
     def __init__(self, host, device_id, optimistic=False, timeout=DEFAULT_TIMEOUT):
         """Initialize the device."""
@@ -156,7 +154,9 @@ class MediaroomDevice(MediaPlayerEntity):
         )
         self._channel = None
         self._optimistic = optimistic
-        self._state = STATE_PLAYING if optimistic else STATE_STANDBY
+        self._attr_state = (
+            MediaPlayerState.PLAYING if optimistic else MediaPlayerState.STANDBY
+        )
         self._name = f"Mediaroom {device_id if device_id else host}"
         self._available = True
         if device_id:
@@ -169,7 +169,7 @@ class MediaroomDevice(MediaPlayerEntity):
         """Return True if entity is available."""
         return self._available
 
-    async def async_added_to_hass(self):
+    async def async_added_to_hass(self) -> None:
         """Retrieve latest state."""
 
         async def async_notify_received(notify):
@@ -179,7 +179,7 @@ class MediaroomDevice(MediaPlayerEntity):
             if not stb_state:
                 return
             self.set_state(stb_state)
-            _LOGGER.debug("STB(%s) is [%s]", self.host, self._state)
+            _LOGGER.debug("STB(%s) is [%s]", self.host, self.state)
             self._available = True
             self.async_write_ha_state()
 
@@ -189,29 +189,33 @@ class MediaroomDevice(MediaPlayerEntity):
             )
         )
 
-    async def async_play_media(self, media_type, media_id, **kwargs):
+    async def async_play_media(
+        self, media_type: MediaType | str, media_id: str, **kwargs: Any
+    ) -> None:
         """Play media."""
 
         _LOGGER.debug(
             "STB(%s) Play media: %s (%s)", self.stb.stb_ip, media_id, media_type
         )
-        if media_type == MEDIA_TYPE_CHANNEL:
+        command: str | int
+        if media_type == MediaType.CHANNEL:
             if not media_id.isdigit():
                 _LOGGER.error("Invalid media_id %s: Must be a channel number", media_id)
                 return
-            media_id = int(media_id)
+            command = int(media_id)
         elif media_type == MEDIA_TYPE_MEDIAROOM:
             if media_id not in COMMANDS:
                 _LOGGER.error("Invalid media_id %s: Must be a command", media_id)
                 return
+            command = media_id
         else:
             _LOGGER.error("Invalid media type %s", media_type)
             return
 
         try:
-            await self.stb.send_cmd(media_id)
+            await self.stb.send_cmd(command)
             if self._optimistic:
-                self._state = STATE_PLAYING
+                self._attr_state = MediaPlayerState.PLAYING
             self._available = True
         except PyMediaroomError:
             self._available = False
@@ -227,107 +231,97 @@ class MediaroomDevice(MediaPlayerEntity):
         """Return the name of the device."""
         return self._name
 
-    @property
-    def state(self):
-        """Return the state of the device."""
-        return self._state
-
-    @property
-    def media_content_type(self):
-        """Return the content type of current playing media."""
-        return MEDIA_TYPE_CHANNEL
-
     @property
     def media_channel(self):
         """Channel currently playing."""
         return self._channel
 
-    async def async_turn_on(self):
+    async def async_turn_on(self) -> None:
         """Turn on the receiver."""
 
         try:
             self.set_state(await self.stb.turn_on())
             if self._optimistic:
-                self._state = STATE_PLAYING
+                self._attr_state = MediaPlayerState.PLAYING
             self._available = True
         except PyMediaroomError:
             self._available = False
         self.async_write_ha_state()
 
-    async def async_turn_off(self):
+    async def async_turn_off(self) -> None:
         """Turn off the receiver."""
 
         try:
             self.set_state(await self.stb.turn_off())
             if self._optimistic:
-                self._state = STATE_STANDBY
+                self._attr_state = MediaPlayerState.STANDBY
             self._available = True
         except PyMediaroomError:
             self._available = False
         self.async_write_ha_state()
 
-    async def async_media_play(self):
+    async def async_media_play(self) -> None:
         """Send play command."""
 
         try:
             _LOGGER.debug("media_play()")
             await self.stb.send_cmd("PlayPause")
             if self._optimistic:
-                self._state = STATE_PLAYING
+                self._attr_state = MediaPlayerState.PLAYING
             self._available = True
         except PyMediaroomError:
             self._available = False
         self.async_write_ha_state()
 
-    async def async_media_pause(self):
+    async def async_media_pause(self) -> None:
         """Send pause command."""
 
         try:
             await self.stb.send_cmd("PlayPause")
             if self._optimistic:
-                self._state = STATE_PAUSED
+                self._attr_state = MediaPlayerState.PAUSED
             self._available = True
         except PyMediaroomError:
             self._available = False
         self.async_write_ha_state()
 
-    async def async_media_stop(self):
+    async def async_media_stop(self) -> None:
         """Send stop command."""
 
         try:
             await self.stb.send_cmd("Stop")
             if self._optimistic:
-                self._state = STATE_PAUSED
+                self._attr_state = MediaPlayerState.PAUSED
             self._available = True
         except PyMediaroomError:
             self._available = False
         self.async_write_ha_state()
 
-    async def async_media_previous_track(self):
+    async def async_media_previous_track(self) -> None:
         """Send Program Down command."""
 
         try:
             await self.stb.send_cmd("ProgDown")
             if self._optimistic:
-                self._state = STATE_PLAYING
+                self._attr_state = MediaPlayerState.PLAYING
             self._available = True
         except PyMediaroomError:
             self._available = False
         self.async_write_ha_state()
 
-    async def async_media_next_track(self):
+    async def async_media_next_track(self) -> None:
         """Send Program Up command."""
 
         try:
             await self.stb.send_cmd("ProgUp")
             if self._optimistic:
-                self._state = STATE_PLAYING
+                self._attr_state = MediaPlayerState.PLAYING
             self._available = True
         except PyMediaroomError:
             self._available = False
         self.async_write_ha_state()
 
-    async def async_volume_up(self):
+    async def async_volume_up(self) -> None:
         """Send volume up command."""
 
         try:
@@ -337,7 +331,7 @@ class MediaroomDevice(MediaPlayerEntity):
             self._available = False
         self.async_write_ha_state()
 
-    async def async_volume_down(self):
+    async def async_volume_down(self) -> None:
         """Send volume up command."""
 
         try:
@@ -346,7 +340,7 @@ class MediaroomDevice(MediaPlayerEntity):
             self._available = False
         self.async_write_ha_state()
 
-    async def async_mute_volume(self, mute):
+    async def async_mute_volume(self, mute: bool) -> None:
         """Send mute command."""
 
         try:
