@@ -121,7 +121,10 @@ async def async_publish(
     if not isinstance(payload, bytes):
         if not encoding:
             _LOGGER.error(
-                "Can't pass-through payload for publishing %s on %s with no encoding set, need 'bytes' got %s",
+                (
+                    "Can't pass-through payload for publishing %s on %s with no"
+                    " encoding set, need 'bytes' got %s"
+                ),
                 payload,
                 topic,
                 type(payload),
@@ -221,8 +224,10 @@ async def async_subscribe(
     if non_default == 3:
         module = inspect.getmodule(msg_callback)
         _LOGGER.warning(
-            "Signature of MQTT msg_callback '%s.%s' is deprecated, "
-            "this will stop working with HA core 2023.2",
+            (
+                "Signature of MQTT msg_callback '%s.%s' is deprecated, "
+                "this will stop working with HA core 2023.2"
+            ),
             module.__name__ if module else "<unknown>",
             msg_callback.__name__,
         )
@@ -303,8 +308,8 @@ class MqttClientSetup:
         # Enable logging
         self._client.enable_logger()
 
-        username = config.get(CONF_USERNAME)
-        password = config.get(CONF_PASSWORD)
+        username: str | None = config.get(CONF_USERNAME)
+        password: str | None = config.get(CONF_PASSWORD)
         if username is not None:
             self._client.username_pw_set(username, password)
 
@@ -317,8 +322,8 @@ class MqttClientSetup:
         client_cert = get_file_path(CONF_CLIENT_CERT, config.get(CONF_CLIENT_CERT))
         tls_insecure = config.get(CONF_TLS_INSECURE)
         if transport == TRANSPORT_WEBSOCKETS:
-            ws_path = config.get(CONF_WS_PATH)
-            ws_headers = config.get(CONF_WS_HEADERS)
+            ws_path: str = config[CONF_WS_PATH]
+            ws_headers: dict[str, str] = config[CONF_WS_HEADERS]
             self._client.ws_set_options(ws_path, ws_headers)
         if certificate is not None:
             self._client.tls_set(
@@ -340,6 +345,8 @@ class MqttClientSetup:
 class MQTT:
     """Home Assistant MQTT client."""
 
+    _mqttc: mqtt.Client
+
     def __init__(
         self,
         hass: HomeAssistant,
@@ -347,10 +354,6 @@ class MQTT:
         conf: ConfigType,
     ) -> None:
         """Initialize Home Assistant MQTT client."""
-        # We don't import on the top because some integrations
-        # should be able to optionally rely on MQTT.
-        import paho.mqtt.client as mqtt  # pylint: disable=import-outside-toplevel
-
         self._mqtt_data = get_mqtt_data(hass)
 
         self.hass = hass
@@ -360,7 +363,6 @@ class MQTT:
         self.connected = False
         self._ha_started = asyncio.Event()
         self._last_subscribe = time.time()
-        self._mqttc: mqtt.Client = None
         self._cleanup_on_unload: list[Callable[[], None]] = []
 
         self._paho_lock = asyncio.Lock()  # Prevents parallel calls to the MQTT client
@@ -427,11 +429,12 @@ class MQTT:
                 self._mqttc.publish, topic, payload, qos, retain
             )
             _LOGGER.debug(
-                "Transmitting%s message on %s: '%s', mid: %s",
+                "Transmitting%s message on %s: '%s', mid: %s, qos: %s",
                 " retained" if retain else "",
                 topic,
                 payload,
                 msg_info.mid,
+                qos,
             )
             _raise_on_error(msg_info.rc)
         await self._wait_for_mid(msg_info.mid)
@@ -525,12 +528,9 @@ class MQTT:
         """
 
         def _client_unsubscribe(topic: str) -> int:
-            result: int | None = None
-            mid: int | None = None
             result, mid = self._mqttc.unsubscribe(topic)
             _LOGGER.debug("Unsubscribing from %s, mid: %s", topic, mid)
             _raise_on_error(result)
-            assert mid
             return mid
 
         if any(other.topic == topic for other in self.subscriptions):
@@ -554,7 +554,7 @@ class MQTT:
             for topic, qos in subscriptions:
                 result, mid = self._mqttc.subscribe(topic, qos)
                 subscribe_result_list.append((result, mid))
-                _LOGGER.debug("Subscribing to %s, mid: %s", topic, mid)
+                _LOGGER.debug("Subscribing to %s, mid: %s, qos: %s", topic, mid, qos)
             return subscribe_result_list
 
         async with self._paho_lock:
@@ -562,8 +562,8 @@ class MQTT:
                 _process_client_subscriptions
             )
 
-        tasks = []
-        errors = []
+        tasks: list[Coroutine[Any, Any, None]] = []
+        errors: list[int] = []
         for result, mid in results:
             if result == 0:
                 tasks.append(self._wait_for_mid(mid))
@@ -657,9 +657,10 @@ class MQTT:
     @callback
     def _mqtt_handle_message(self, msg: mqtt.MQTTMessage) -> None:
         _LOGGER.debug(
-            "Received%s message on %s: %s",
+            "Received%s message on %s (qos=%s): %s",
             " retained" if msg.retain else "",
             msg.topic,
+            msg.qos,
             msg.payload[0:8192],
         )
         timestamp = dt_util.utcnow()
@@ -775,7 +776,7 @@ class MQTT:
             )
 
 
-def _raise_on_errors(result_codes: Iterable[int | None]) -> None:
+def _raise_on_errors(result_codes: Iterable[int]) -> None:
     """Raise error if error result."""
     # pylint: disable-next=import-outside-toplevel
     import paho.mqtt.client as mqtt
@@ -788,7 +789,7 @@ def _raise_on_errors(result_codes: Iterable[int | None]) -> None:
         raise HomeAssistantError(f"Error talking to MQTT: {', '.join(messages)}")
 
 
-def _raise_on_error(result_code: int | None) -> None:
+def _raise_on_error(result_code: int) -> None:
     """Raise error if error result."""
     _raise_on_errors((result_code,))
 
