@@ -17,9 +17,9 @@ from homeassistant.const import (
     CONCENTRATION_MICROGRAMS_PER_CUBIC_METER,
     CONCENTRATION_PARTS_PER_MILLION,
     PERCENTAGE,
-    PRESSURE_HPA,
     SIGNAL_STRENGTH_DECIBELS_MILLIWATT,
-    TEMP_CELSIUS,
+    UnitOfPressure,
+    UnitOfTemperature,
 )
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers import entity_registry
@@ -81,42 +81,42 @@ SENSORS: tuple[SensorEntityDescription, ...] = (
     SensorEntityDescription(
         key=ATTR_BME280_PRESSURE,
         name="BME280 pressure",
-        native_unit_of_measurement=PRESSURE_HPA,
+        native_unit_of_measurement=UnitOfPressure.HPA,
         device_class=SensorDeviceClass.PRESSURE,
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_BME280_TEMPERATURE,
         name="BME280 temperature",
-        native_unit_of_measurement=TEMP_CELSIUS,
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_BMP180_PRESSURE,
         name="BMP180 pressure",
-        native_unit_of_measurement=PRESSURE_HPA,
+        native_unit_of_measurement=UnitOfPressure.HPA,
         device_class=SensorDeviceClass.PRESSURE,
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_BMP180_TEMPERATURE,
         name="BMP180 temperature",
-        native_unit_of_measurement=TEMP_CELSIUS,
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_BMP280_PRESSURE,
         name="BMP280 pressure",
-        native_unit_of_measurement=PRESSURE_HPA,
+        native_unit_of_measurement=UnitOfPressure.HPA,
         device_class=SensorDeviceClass.PRESSURE,
         state_class=SensorStateClass.MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_BMP280_TEMPERATURE,
         name="BMP280 temperature",
-        native_unit_of_measurement=TEMP_CELSIUS,
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         state_class=SensorStateClass.MEASUREMENT,
     ),
@@ -130,7 +130,7 @@ SENSORS: tuple[SensorEntityDescription, ...] = (
     SensorEntityDescription(
         key=ATTR_HECA_TEMPERATURE,
         name="HECA temperature",
-        native_unit_of_measurement=TEMP_CELSIUS,
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         state_class=SensorStateClass.MEASUREMENT,
     ),
@@ -150,7 +150,9 @@ SENSORS: tuple[SensorEntityDescription, ...] = (
         key=ATTR_PMSX003_CAQI_LEVEL,
         name="PMSx003 CAQI level",
         icon="mdi:air-filter",
-        device_class="nam__caqi_level",
+        device_class=SensorDeviceClass.ENUM,
+        options=["very low", "low", "medium", "high", "very high"],
+        translation_key="caqi_level",
     ),
     SensorEntityDescription(
         key=ATTR_PMSX003_P0,
@@ -182,7 +184,9 @@ SENSORS: tuple[SensorEntityDescription, ...] = (
         key=ATTR_SDS011_CAQI_LEVEL,
         name="SDS011 CAQI level",
         icon="mdi:air-filter",
-        device_class="nam__caqi_level",
+        device_class=SensorDeviceClass.ENUM,
+        options=["very low", "low", "medium", "high", "very high"],
+        translation_key="caqi_level",
     ),
     SensorEntityDescription(
         key=ATTR_SDS011_P1,
@@ -208,7 +212,7 @@ SENSORS: tuple[SensorEntityDescription, ...] = (
     SensorEntityDescription(
         key=ATTR_SHT3X_TEMPERATURE,
         name="SHT3X temperature",
-        native_unit_of_measurement=TEMP_CELSIUS,
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         state_class=SensorStateClass.MEASUREMENT,
     ),
@@ -221,7 +225,9 @@ SENSORS: tuple[SensorEntityDescription, ...] = (
         key=ATTR_SPS30_CAQI_LEVEL,
         name="SPS30 CAQI level",
         icon="mdi:air-filter",
-        device_class="nam__caqi_level",
+        device_class=SensorDeviceClass.ENUM,
+        options=["very low", "low", "medium", "high", "very high"],
+        translation_key="caqi_level",
     ),
     SensorEntityDescription(
         key=ATTR_SPS30_P0,
@@ -261,7 +267,7 @@ SENSORS: tuple[SensorEntityDescription, ...] = (
     SensorEntityDescription(
         key=ATTR_DHT22_TEMPERATURE,
         name="DHT22 temperature",
-        native_unit_of_measurement=TEMP_CELSIUS,
+        native_unit_of_measurement=UnitOfTemperature.CELSIUS,
         device_class=SensorDeviceClass.TEMPERATURE,
         state_class=SensorStateClass.MEASUREMENT,
     ),
