@@ -21,6 +21,7 @@ CONF_URL_SECURITY = "https://home.netatmo.com/security"
 CONF_URL_ENERGY = "https://my.netatmo.com/app/energy"
 CONF_URL_WEATHER = "https://my.netatmo.com/app/weather"
 CONF_URL_CONTROL = "https://home.netatmo.com/control"
+CONF_URL_PUBLIC_WEATHER = "https://weathermap.netatmo.com/"
 
 AUTH = "netatmo_auth"
 CONF_PUBLIC = "public_sensor_config"
@@ -49,7 +50,6 @@ CONF_LON_NE = "lon_ne"
 CONF_LON_SW = "lon_sw"
 CONF_NEW_AREA = "new_area"
 CONF_PUBLIC_MODE = "mode"
-CONF_UUID = "uuid"
 CONF_WEATHER_AREAS = "weather_areas"
 
 OAUTH2_AUTHORIZE = "https://api.netatmo.com/oauth2/authorize"
