@@ -1,9 +1,9 @@
 """The Recorder websocket API."""
 from __future__ import annotations
 
-from datetime import datetime as dt, timedelta
+from datetime import datetime as dt
 import logging
-from typing import Any, Literal
+from typing import Any, Literal, cast
 
 import voluptuous as vol
 
@@ -26,6 +26,7 @@ from homeassistant.util.unit_conversion import (
 )
 
 from .const import MAX_QUEUE_BACKLOG
+from .models import StatisticPeriod
 from .statistics import (
     STATISTIC_UNIT_TO_UNIT_CONVERTER,
     async_add_external_statistics,
@@ -36,7 +37,13 @@ from .statistics import (
     statistics_during_period,
     validate_statistics,
 )
-from .util import async_migration_in_progress, async_migration_is_live, get_instance
+from .util import (
+    PERIOD_SCHEMA,
+    async_migration_in_progress,
+    async_migration_is_live,
+    get_instance,
+    resolve_period,
+)
 
 _LOGGER: logging.Logger = logging.getLogger(__package__)
 
@@ -65,7 +72,7 @@ def _ws_get_statistic_during_period(
     start_time: dt | None,
     end_time: dt | None,
     statistic_id: str,
-    types: set[str] | None,
+    types: set[Literal["max", "mean", "min", "change"]] | None,
     units: dict[str, str],
 ) -> str:
     """Fetch statistics and convert them to json in the executor."""
@@ -82,26 +89,10 @@ def _ws_get_statistic_during_period(
 @websocket_api.websocket_command(
     {
         vol.Required("type"): "recorder/statistic_during_period",
-        vol.Exclusive("calendar", "period"): vol.Schema(
-            {
-                vol.Required("period"): vol.Any("hour", "day", "week", "month", "year"),
-                vol.Optional("offset"): int,
-            }
-        ),
-        vol.Exclusive("fixed_period", "period"): vol.Schema(
-            {
-                vol.Optional("start_time"): str,
-                vol.Optional("end_time"): str,
-            }
-        ),
-        vol.Exclusive("rolling_window", "period"): vol.Schema(
-            {
-                vol.Required("duration"): cv.time_period_dict,
-                vol.Optional("offset"): cv.time_period_dict,
-            }
-        ),
         vol.Optional("statistic_id"): str,
-        vol.Optional("types"): vol.All([str], vol.Coerce(set)),
+        vol.Optional("types"): vol.All(
+            [vol.Any("max", "mean", "min", "change")], vol.Coerce(set)
+        ),
         vol.Optional("units"): vol.Schema(
             {
                 vol.Optional("distance"): vol.In(DistanceConverter.VALID_UNITS),
@@ -114,6 +105,7 @@ def _ws_get_statistic_during_period(
                 vol.Optional("volume"): vol.In(VolumeConverter.VALID_UNITS),
             }
         ),
+        **PERIOD_SCHEMA.schema,
     }
 )
 @websocket_api.async_response
@@ -126,67 +118,7 @@ async def ws_get_statistic_during_period(
     if "offset" in msg and "duration" not in msg:
         raise HomeAssistantError
 
-    start_time = None
-    end_time = None
-
-    if "calendar" in msg:
-        calendar_period = msg["calendar"]["period"]
-        start_of_day = dt_util.start_of_local_day()
-        offset = msg["calendar"].get("offset", 0)
-        if calendar_period == "hour":
-            start_time = dt_util.now().replace(minute=0, second=0, microsecond=0)
-            start_time += timedelta(hours=offset)
-            end_time = start_time + timedelta(hours=1)
-        elif calendar_period == "day":
-            start_time = start_of_day
-            start_time += timedelta(days=offset)
-            end_time = start_time + timedelta(days=1)
-        elif calendar_period == "week":
-            start_time = start_of_day - timedelta(days=start_of_day.weekday())
-            start_time += timedelta(days=offset * 7)
-            end_time = start_time + timedelta(weeks=1)
-        elif calendar_period == "month":
-            start_time = start_of_day.replace(day=28)
-            # This works for up to 48 months of offset
-            start_time = (start_time + timedelta(days=offset * 31)).replace(day=1)
-            end_time = (start_time + timedelta(days=31)).replace(day=1)
-        else:  # calendar_period = "year"
-            start_time = start_of_day.replace(month=12, day=31)
-            # This works for 100+ years of offset
-            start_time = (start_time + timedelta(days=offset * 366)).replace(
-                month=1, day=1
-            )
-            end_time = (start_time + timedelta(days=365)).replace(day=1)
-
-        start_time = dt_util.as_utc(start_time)
-        end_time = dt_util.as_utc(end_time)
-
-    elif "fixed_period" in msg:
-        if start_time_str := msg["fixed_period"].get("start_time"):
-            if start_time := dt_util.parse_datetime(start_time_str):
-                start_time = dt_util.as_utc(start_time)
-            else:
-                connection.send_error(
-                    msg["id"], "invalid_start_time", "Invalid start_time"
-                )
-                return
-
-        if end_time_str := msg["fixed_period"].get("end_time"):
-            if end_time := dt_util.parse_datetime(end_time_str):
-                end_time = dt_util.as_utc(end_time)
-            else:
-                connection.send_error(msg["id"], "invalid_end_time", "Invalid end_time")
-                return
-
-    elif "rolling_window" in msg:
-        duration = msg["rolling_window"]["duration"]
-        now = dt_util.utcnow()
-        start_time = now - duration
-        end_time = start_time + duration
-
-        if offset := msg["rolling_window"].get("offset"):
-            start_time += offset
-            end_time += offset
+    start_time, end_time = resolve_period(cast(StatisticPeriod, msg))
 
     connection.send_message(
         await get_instance(hass).async_add_executor_job(
@@ -210,16 +142,27 @@ def _ws_get_statistics_during_period(
     statistic_ids: list[str] | None,
     period: Literal["5minute", "day", "hour", "week", "month"],
     units: dict[str, str],
+    types: set[Literal["last_reset", "max", "mean", "min", "state", "sum"]],
 ) -> str:
     """Fetch statistics and convert them to json in the executor."""
-    return JSON_DUMP(
-        messages.result_message(
-            msg_id,
-            statistics_during_period(
-                hass, start_time, end_time, statistic_ids, period, units=units
-            ),
-        )
+    result = statistics_during_period(
+        hass,
+        start_time,
+        end_time,
+        statistic_ids,
+        period,
+        units,
+        types,
     )
+    for statistic_id in result:
+        for item in result[statistic_id]:
+            if (start := item.get("start")) is not None:
+                item["start"] = int(start.timestamp() * 1000)
+            if (end := item.get("end")) is not None:
+                item["end"] = int(end.timestamp() * 1000)
+            if (last_reset := item.get("last_reset")) is not None:
+                item["last_reset"] = int(last_reset.timestamp() * 1000)
+    return JSON_DUMP(messages.result_message(msg_id, result))
 
 
 async def ws_handle_get_statistics_during_period(
@@ -244,6 +187,8 @@ async def ws_handle_get_statistics_during_period(
     else:
         end_time = None
 
+    if (types := msg.get("types")) is None:
+        types = {"last_reset", "max", "mean", "min", "state", "sum"}
     connection.send_message(
         await get_instance(hass).async_add_executor_job(
             _ws_get_statistics_during_period,
@@ -254,6 +199,7 @@ async def ws_handle_get_statistics_during_period(
             msg.get("statistic_ids"),
             msg.get("period"),
             msg.get("units"),
+            types,
         )
     )
 
@@ -277,6 +223,10 @@ async def ws_handle_get_statistics_during_period(
                 vol.Optional("volume"): vol.In(VolumeConverter.VALID_UNITS),
             }
         ),
+        vol.Optional("types"): vol.All(
+            [vol.Any("last_reset", "max", "mean", "min", "state", "sum")],
+            vol.Coerce(set),
+        ),
     }
 )
 @websocket_api.async_response
