@@ -12,7 +12,7 @@ from homeassistant.components.climate import (
     HVACMode,
 )
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import ATTR_TEMPERATURE, TEMP_CELSIUS, TEMP_FAHRENHEIT
+from homeassistant.const import ATTR_TEMPERATURE, UnitOfTemperature
 from homeassistant.core import HomeAssistant
 from homeassistant.exceptions import HomeAssistantError
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
@@ -98,8 +98,8 @@ class ScreenLogicClimate(ScreenlogicEntity, ClimateEntity, RestoreEntity):
     def temperature_unit(self) -> str:
         """Return the unit of measurement."""
         if self.config_data["is_celsius"]["value"] == 1:
-            return TEMP_CELSIUS
-        return TEMP_FAHRENHEIT
+            return UnitOfTemperature.CELSIUS
+        return UnitOfTemperature.FAHRENHEIT
 
     @property
     def hvac_mode(self) -> HVACMode:
@@ -142,7 +142,8 @@ class ScreenLogicClimate(ScreenlogicEntity, ClimateEntity, RestoreEntity):
             await self._async_refresh()
         else:
             raise HomeAssistantError(
-                f"Failed to set_temperature {temperature} on body {self.body['body_type']['value']}"
+                f"Failed to set_temperature {temperature} on body"
+                f" {self.body['body_type']['value']}"
             )
 
     async def async_set_hvac_mode(self, hvac_mode: HVACMode) -> None:
@@ -156,7 +157,8 @@ class ScreenLogicClimate(ScreenlogicEntity, ClimateEntity, RestoreEntity):
             await self._async_refresh()
         else:
             raise HomeAssistantError(
-                f"Failed to set_hvac_mode {mode} on body {self.body['body_type']['value']}"
+                f"Failed to set_hvac_mode {mode} on body"
+                f" {self.body['body_type']['value']}"
             )
 
     async def async_set_preset_mode(self, preset_mode: str) -> None:
@@ -170,7 +172,8 @@ class ScreenLogicClimate(ScreenlogicEntity, ClimateEntity, RestoreEntity):
             await self._async_refresh()
         else:
             raise HomeAssistantError(
-                f"Failed to set_preset_mode {mode} on body {self.body['body_type']['value']}"
+                f"Failed to set_preset_mode {mode} on body"
+                f" {self.body['body_type']['value']}"
             )
 
     async def async_added_to_hass(self) -> None:
