@@ -475,6 +475,11 @@ class ShellyRpcCoordinator(DataUpdateCoordinator[None]):
 
     async def _async_disconnected(self) -> None:
         """Handle device disconnected."""
+        # Sleeping devices send data and disconnects
+        # There are no disconnect events for sleeping devices
+        if self.entry.data.get(CONF_SLEEP_PERIOD):
+            return
+
         async with self._connection_lock:
             if not self.connected:  # Already disconnected
                 return
@@ -655,7 +660,8 @@ async def async_reconnect_soon(
 ) -> None:
     """Try to reconnect soon."""
     if (
-        not hass.is_stopping
+        not entry.data.get(CONF_SLEEP_PERIOD)
+        and not hass.is_stopping
         and entry.state == config_entries.ConfigEntryState.LOADED
         and (entry_data := get_entry_data(hass).get(entry.entry_id))
         and (coordinator := entry_data.rpc)
