@@ -1,7 +1,7 @@
 """Provides the data update coordinators for SolarEdge."""
 from __future__ import annotations
 
-from abc import abstractmethod
+from abc import ABC, abstractmethod
 from datetime import date, datetime, timedelta
 from typing import Any
 
@@ -21,7 +21,7 @@ from .const import (
 )
 
 
-class SolarEdgeDataService:
+class SolarEdgeDataService(ABC):
     """Get and update the latest data."""
 
     coordinator: DataUpdateCoordinator
@@ -262,7 +262,8 @@ class SolarEdgePowerFlowDataService(SolarEdgeDataService):
 
         if "connections" not in power_flow:
             LOGGER.debug(
-                "Missing connections in power flow data. Assuming site does not have any"
+                "Missing connections in power flow data. Assuming site does not"
+                " have any"
             )
             return
 
@@ -276,17 +277,19 @@ class SolarEdgePowerFlowDataService(SolarEdgeDataService):
 
         for key, value in power_flow.items():
             if key in ["LOAD", "PV", "GRID", "STORAGE"]:
-                self.data[key] = value["currentPower"]
+                self.data[key] = value.get("currentPower")
                 self.attributes[key] = {"status": value["status"]}
 
             if key in ["GRID"]:
                 export = key.lower() in power_to
-                self.data[key] *= -1 if export else 1
+                if self.data[key]:
+                    self.data[key] *= -1 if export else 1
                 self.attributes[key]["flow"] = "export" if export else "import"
 
             if key in ["STORAGE"]:
                 charge = key.lower() in power_to
-                self.data[key] *= -1 if charge else 1
+                if self.data[key]:
+                    self.data[key] *= -1 if charge else 1
                 self.attributes[key]["flow"] = "charge" if charge else "discharge"
                 self.attributes[key]["soc"] = value["chargeLevel"]
 
