@@ -1,12 +1,9 @@
 """Support for Synology DSM binary sensors."""
 from __future__ import annotations
 
-from collections.abc import Mapping
 from dataclasses import dataclass
-from typing import Any
 
 from synology_dsm.api.core.security import SynoCoreSecurity
-from synology_dsm.api.core.upgrade import SynoCoreUpgrade
 from synology_dsm.api.storage.storage import SynoStorage
 
 from homeassistant.components.binary_sensor import (
@@ -19,10 +16,10 @@ from homeassistant.const import CONF_DISKS
 from homeassistant.core import HomeAssistant
 from homeassistant.helpers.entity import EntityCategory
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
-from homeassistant.helpers.update_coordinator import DataUpdateCoordinator
 
 from . import SynoApi
 from .const import DOMAIN
+from .coordinator import SynologyDSMCentralUpdateCoordinator
 from .entity import (
     SynologyDSMBaseEntity,
     SynologyDSMDeviceEntity,
@@ -38,18 +35,6 @@ class SynologyDSMBinarySensorEntityDescription(
     """Describes Synology DSM binary sensor entity."""
 
 
-UPGRADE_BINARY_SENSORS: tuple[SynologyDSMBinarySensorEntityDescription, ...] = (
-    SynologyDSMBinarySensorEntityDescription(
-        # Deprecated, scheduled to be removed in 2022.6 (#68664)
-        api_key=SynoCoreUpgrade.API_KEY,
-        key="update_available",
-        name="Update Available",
-        entity_registry_enabled_default=False,
-        device_class=BinarySensorDeviceClass.UPDATE,
-        entity_category=EntityCategory.DIAGNOSTIC,
-    ),
-)
-
 SECURITY_BINARY_SENSORS: tuple[SynologyDSMBinarySensorEntityDescription, ...] = (
     SynologyDSMBinarySensorEntityDescription(
         api_key=SynoCoreSecurity.API_KEY,
@@ -85,22 +70,11 @@ async def async_setup_entry(
     api = data.api
     coordinator = data.coordinator_central
 
-    entities: list[
-        SynoDSMSecurityBinarySensor
-        | SynoDSMUpgradeBinarySensor
-        | SynoDSMStorageBinarySensor
-    ] = [
+    entities: list[SynoDSMSecurityBinarySensor | SynoDSMStorageBinarySensor] = [
         SynoDSMSecurityBinarySensor(api, coordinator, description)
         for description in SECURITY_BINARY_SENSORS
     ]
 
-    entities.extend(
-        [
-            SynoDSMUpgradeBinarySensor(api, coordinator, description)
-            for description in UPGRADE_BINARY_SENSORS
-        ]
-    )
-
     # Handle all disks
     if api.storage.disks_ids:
         entities.extend(
@@ -114,7 +88,9 @@ async def async_setup_entry(
     async_add_entities(entities)
 
 
-class SynoDSMBinarySensor(SynologyDSMBaseEntity, BinarySensorEntity):
+class SynoDSMBinarySensor(
+    SynologyDSMBaseEntity[SynologyDSMCentralUpdateCoordinator], BinarySensorEntity
+):
     """Mixin for binary sensor specific attributes."""
 
     entity_description: SynologyDSMBinarySensorEntityDescription
@@ -122,7 +98,7 @@ class SynoDSMBinarySensor(SynologyDSMBaseEntity, BinarySensorEntity):
     def __init__(
         self,
         api: SynoApi,
-        coordinator: DataUpdateCoordinator[dict[str, dict[str, Any]]],
+        coordinator: SynologyDSMCentralUpdateCoordinator,
         description: SynologyDSMBinarySensorEntityDescription,
     ) -> None:
         """Initialize the Synology DSM binary_sensor entity."""
@@ -156,7 +132,7 @@ class SynoDSMStorageBinarySensor(SynologyDSMDeviceEntity, SynoDSMBinarySensor):
     def __init__(
         self,
         api: SynoApi,
-        coordinator: DataUpdateCoordinator[dict[str, dict[str, Any]]],
+        coordinator: SynologyDSMCentralUpdateCoordinator,
         description: SynologyDSMBinarySensorEntityDescription,
         device_id: str | None = None,
     ) -> None:
@@ -169,25 +145,3 @@ class SynoDSMStorageBinarySensor(SynologyDSMDeviceEntity, SynoDSMBinarySensor):
         return bool(
             getattr(self._api.storage, self.entity_description.key)(self._device_id)
         )
-
-
-class SynoDSMUpgradeBinarySensor(SynoDSMBinarySensor):
-    """Representation a Synology Upgrade binary sensor."""
-
-    @property
-    def is_on(self) -> bool:
-        """Return the state."""
-        return bool(getattr(self._api.upgrade, self.entity_description.key))
-
-    @property
-    def available(self) -> bool:
-        """Return True if entity is available."""
-        return bool(self._api.upgrade)
-
-    @property
-    def extra_state_attributes(self) -> Mapping[str, Any] | None:
-        """Return firmware details."""
-        return {
-            "installed_version": self._api.information.version_string,
-            "latest_available_version": self._api.upgrade.available_version,
-        }
