@@ -2,20 +2,21 @@
 from __future__ import annotations
 
 import logging
+from typing import Any
 
 import voluptuous as vol
 
-from homeassistant.components.climate import ClimateEntity
-from homeassistant.components.climate.const import (
+from homeassistant.components.climate import (
     FAN_AUTO,
     PRESET_AWAY,
     PRESET_HOME,
+    ClimateEntity,
     ClimateEntityFeature,
     HVACAction,
     HVACMode,
 )
 from homeassistant.config_entries import ConfigEntry
-from homeassistant.const import ATTR_TEMPERATURE, PRECISION_TENTHS, TEMP_CELSIUS
+from homeassistant.const import ATTR_TEMPERATURE, PRECISION_TENTHS, UnitOfTemperature
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers import config_validation as cv, entity_platform
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
@@ -103,8 +104,7 @@ async def async_setup_entry(
         "set_temp_offset",
     )
 
-    if entities:
-        async_add_entities(entities, True)
+    async_add_entities(entities, True)
 
 
 def _generate_entities(tado):
@@ -213,7 +213,7 @@ def create_climate_entity(tado, name: str, zone_id: int, device_info: dict):
 class TadoClimate(TadoZoneEntity, ClimateEntity):
     """Representation of a Tado climate entity."""
 
-    _attr_temperature_unit = TEMP_CELSIUS
+    _attr_temperature_unit = UnitOfTemperature.CELSIUS
 
     def __init__(
         self,
@@ -245,7 +245,7 @@ class TadoClimate(TadoZoneEntity, ClimateEntity):
         self._ac_device = zone_type == TYPE_AIR_CONDITIONING
         self._supported_hvac_modes = supported_hvac_modes
         self._supported_fan_modes = supported_fan_modes
-        self._support_flags = support_flags
+        self._attr_supported_features = support_flags
 
         self._available = False
 
@@ -273,7 +273,7 @@ class TadoClimate(TadoZoneEntity, ClimateEntity):
 
         self._async_update_zone_data()
 
-    async def async_added_to_hass(self):
+    async def async_added_to_hass(self) -> None:
         """Register for sensor updates."""
 
         self.async_on_remove(
@@ -286,11 +286,6 @@ class TadoClimate(TadoZoneEntity, ClimateEntity):
             )
         )
 
-    @property
-    def supported_features(self):
-        """Return the list of supported features."""
-        return self._support_flags
-
     @property
     def name(self):
         """Return the name of the entity."""
@@ -349,7 +344,7 @@ class TadoClimate(TadoZoneEntity, ClimateEntity):
         """List of available fan modes."""
         return self._supported_fan_modes
 
-    def set_fan_mode(self, fan_mode: str):
+    def set_fan_mode(self, fan_mode: str) -> None:
         """Turn fan on/off."""
         self._control_hvac(fan_mode=HA_TO_TADO_FAN_MODE_MAP[fan_mode])
 
@@ -365,7 +360,7 @@ class TadoClimate(TadoZoneEntity, ClimateEntity):
         """Return a list of available preset modes."""
         return SUPPORT_PRESET
 
-    def set_preset_mode(self, preset_mode):
+    def set_preset_mode(self, preset_mode: str) -> None:
         """Set new preset mode."""
         self._tado.set_presence(preset_mode)
 
@@ -406,7 +401,7 @@ class TadoClimate(TadoZoneEntity, ClimateEntity):
 
         self._tado.set_temperature_offset(self._device_id, offset)
 
-    def set_temperature(self, **kwargs):
+    def set_temperature(self, **kwargs: Any) -> None:
         """Set new target temperature."""
         if (temperature := kwargs.get(ATTR_TEMPERATURE)) is None:
             return
@@ -428,7 +423,7 @@ class TadoClimate(TadoZoneEntity, ClimateEntity):
         self._control_hvac(hvac_mode=HA_TO_TADO_HVAC_MODE_MAP[hvac_mode])
 
     @property
-    def available(self):
+    def available(self) -> bool:
         """Return if the device is available."""
         return self._tado_zone_data.available
 
@@ -466,7 +461,7 @@ class TadoClimate(TadoZoneEntity, ClimateEntity):
     @property
     def swing_modes(self):
         """Swing modes for the device."""
-        if self._support_flags & ClimateEntityFeature.SWING_MODE:
+        if self.supported_features & ClimateEntityFeature.SWING_MODE:
             return [TADO_SWING_ON, TADO_SWING_OFF]
         return None
 
@@ -482,7 +477,7 @@ class TadoClimate(TadoZoneEntity, ClimateEntity):
         ] = self._tado_zone_data.default_overlay_termination_duration
         return state_attr
 
-    def set_swing_mode(self, swing_mode):
+    def set_swing_mode(self, swing_mode: str) -> None:
         """Set swing modes for the device."""
         self._control_hvac(swing_mode=swing_mode)
 
@@ -603,7 +598,10 @@ class TadoClimate(TadoZoneEntity, ClimateEntity):
             )
 
         _LOGGER.debug(
-            "Switching to %s for zone %s (%d) with temperature %s °C and duration %s using overlay %s",
+            (
+                "Switching to %s for zone %s (%d) with temperature %s °C and duration"
+                " %s using overlay %s"
+            ),
             self._current_tado_hvac_mode,
             self.zone_name,
             self.zone_id,
@@ -618,10 +616,10 @@ class TadoClimate(TadoZoneEntity, ClimateEntity):
             temperature_to_send = None
 
         fan_speed = None
-        if self._support_flags & ClimateEntityFeature.FAN_MODE:
+        if self.supported_features & ClimateEntityFeature.FAN_MODE:
             fan_speed = self._current_tado_fan_speed
         swing = None
-        if self._support_flags & ClimateEntityFeature.SWING_MODE:
+        if self.supported_features & ClimateEntityFeature.SWING_MODE:
             swing = self._current_tado_swing_mode
 
         self._tado.set_zone_overlay(
