@@ -3,7 +3,6 @@ from __future__ import annotations
 
 from datetime import timedelta
 import logging
-from typing import Any
 
 from pyvizio import VizioAsync
 from pyvizio.api.apps import find_app_name
@@ -13,6 +12,7 @@ from homeassistant.components.media_player import (
     MediaPlayerDeviceClass,
     MediaPlayerEntity,
     MediaPlayerEntityFeature,
+    MediaPlayerState,
 )
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import (
@@ -22,8 +22,6 @@ from homeassistant.const import (
     CONF_HOST,
     CONF_INCLUDE,
     CONF_NAME,
-    STATE_OFF,
-    STATE_ON,
 )
 from homeassistant.core import HomeAssistant, callback
 from homeassistant.helpers import entity_platform
@@ -34,8 +32,8 @@ from homeassistant.helpers.dispatcher import (
 )
 from homeassistant.helpers.entity import DeviceInfo
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
-from homeassistant.helpers.update_coordinator import DataUpdateCoordinator
 
+from . import VizioAppsDataUpdateCoordinator
 from .const import (
     CONF_ADDITIONAL_CONFIGS,
     CONF_APPS,
@@ -103,7 +101,10 @@ async def async_setup_entry(
         params["data"] = new_data
 
     if params:
-        hass.config_entries.async_update_entry(config_entry, **params)
+        hass.config_entries.async_update_entry(
+            config_entry,
+            **params,  # type: ignore[arg-type]
+        )
 
     device = VizioAsync(
         DEVICE_ID,
@@ -134,8 +135,8 @@ class VizioDevice(MediaPlayerEntity):
         config_entry: ConfigEntry,
         device: VizioAsync,
         name: str,
-        device_class: str,
-        apps_coordinator: DataUpdateCoordinator,
+        device_class: MediaPlayerDeviceClass,
+        apps_coordinator: VizioAppsDataUpdateCoordinator,
     ) -> None:
         """Initialize Vizio device."""
         self._config_entry = config_entry
@@ -145,8 +146,8 @@ class VizioDevice(MediaPlayerEntity):
         self._current_input = None
         self._current_app_config = None
         self._attr_app_name = None
-        self._available_inputs = []
-        self._available_apps = []
+        self._available_inputs: list[str] = []
+        self._available_apps: list[str] = []
         self._all_apps = apps_coordinator.data if apps_coordinator else None
         self._conf_apps = config_entry.options.get(CONF_APPS, {})
         self._additional_app_configs = config_entry.data.get(CONF_APPS, {}).get(
@@ -195,6 +196,7 @@ class VizioDevice(MediaPlayerEntity):
             self._attr_available = True
 
         if not self._attr_device_info:
+            assert self._attr_unique_id
             self._attr_device_info = DeviceInfo(
                 identifiers={(DOMAIN, self._attr_unique_id)},
                 manufacturer="VIZIO",
@@ -204,7 +206,7 @@ class VizioDevice(MediaPlayerEntity):
             )
 
         if not is_on:
-            self._attr_state = STATE_OFF
+            self._attr_state = MediaPlayerState.OFF
             self._attr_volume_level = None
             self._attr_is_volume_muted = None
             self._current_input = None
@@ -213,7 +215,7 @@ class VizioDevice(MediaPlayerEntity):
             self._attr_sound_mode = None
             return
 
-        self._attr_state = STATE_ON
+        self._attr_state = MediaPlayerState.ON
 
         if audio_settings := await self._device.get_all_settings(
             VIZIO_AUDIO_SETTINGS, log_api_exception=False
@@ -262,7 +264,9 @@ class VizioDevice(MediaPlayerEntity):
 
         # Create list of available known apps from known app list after
         # filtering by CONF_INCLUDE/CONF_EXCLUDE
-        self._available_apps = self._apps_list([app["name"] for app in self._all_apps])
+        self._available_apps = self._apps_list(
+            [app["name"] for app in self._all_apps or ()]
+        )
 
         self._current_app_config = await self._device.get_current_app_config(
             log_api_exception=False
@@ -270,13 +274,13 @@ class VizioDevice(MediaPlayerEntity):
 
         self._attr_app_name = find_app_name(
             self._current_app_config,
-            [APP_HOME, *self._all_apps, *self._additional_app_configs],
+            [APP_HOME, *(self._all_apps or ()), *self._additional_app_configs],
         )
 
         if self._attr_app_name == NO_APP_RUNNING:
             self._attr_app_name = None
 
-    def _get_additional_app_names(self) -> list[dict[str, Any]]:
+    def _get_additional_app_names(self) -> list[str]:
         """Return list of additional apps that were included in configuration.yaml."""
         return [
             additional_app["name"] for additional_app in self._additional_app_configs
