@@ -101,7 +101,10 @@ class ColorChannel(ZigbeeChannel):
         min_mireds = self.cluster.get("color_temp_physical_min", self.MIN_MIREDS)
         if min_mireds == 0:
             self.warning(
-                "[Min mireds is 0, setting to %s] Please open an issue on the quirks repo to have this device corrected",
+                (
+                    "[Min mireds is 0, setting to %s] Please open an issue on the"
+                    " quirks repo to have this device corrected"
+                ),
                 self.MIN_MIREDS,
             )
             min_mireds = self.MIN_MIREDS
@@ -113,7 +116,10 @@ class ColorChannel(ZigbeeChannel):
         max_mireds = self.cluster.get("color_temp_physical_max", self.MAX_MIREDS)
         if max_mireds == 0:
             self.warning(
-                "[Max mireds is 0, setting to %s] Please open an issue on the quirks repo to have this device corrected",
+                (
+                    "[Max mireds is 0, setting to %s] Please open an issue on the"
+                    " quirks repo to have this device corrected"
+                ),
                 self.MAX_MIREDS,
             )
             max_mireds = self.MAX_MIREDS
